/*
 * Jalview - A Sequence Alignment Editor and Viewer
 * Copyright (C) 2005 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package jalview.gui;

import java.awt.*;
import java.awt.datatransfer.*;
import java.awt.event.*;
import javax.swing.*;

import jalview.datamodel.*;
import jalview.io.*;
import jalview.jbgui.*;

public class CutAndPasteTransfer
    extends GCutAndPasteTransfer
{
  public void setForInput()
  {
    getContentPane().add(inputButtonPanel, java.awt.BorderLayout.SOUTH);
  }

  public String getText()
  {
    return textarea.getText();
  }

  public void setText(String text)
  {
    textarea.setText(text);
  }

  public void copyItem_actionPerformed(ActionEvent e)
  {
    Clipboard c = Toolkit.getDefaultToolkit().getSystemClipboard();
    c.setContents(new StringSelection(textarea.getText()), null);
  }

  public void pasteMenu_actionPerformed(ActionEvent e)
  {
    Clipboard c = Toolkit.getDefaultToolkit().getSystemClipboard();
    Transferable contents = c.getContents(this);

    if (contents == null)
    {
      return;
    }

    try
    {
      textarea.setText( (String) contents.getTransferData(
          DataFlavor.stringFlavor));
    }
    catch (Exception ex)
    {
    }
  }

  public void ok_actionPerformed(ActionEvent e)
  {
    String format = IdentifyFile.Identify(getText(), "Paste");
    SequenceI[] sequences = null;

    if (FormatAdapter.formats.contains(format))
    {
      sequences = FormatAdapter.readFile(getText(), "Paste", format);
    }

    if (sequences != null)
    {
      AlignFrame af = new AlignFrame(new Alignment(sequences));
      af.currentFileFormat = format;
      Desktop.addInternalFrame(af, "Cut & Paste input - " + format,
                               AlignFrame.NEW_WINDOW_WIDTH,
                               AlignFrame.NEW_WINDOW_HEIGHT);
      af.statusBar.setText("Successfully pasted alignment file");

      try
      {
        af.setMaximum(Preferences.showFullscreen);
      }
      catch (Exception ex)
      {
      }

      try
      {
        this.setClosed(true);
      }
      catch (Exception ex)
      {
      }
    }
    else
    {
      JOptionPane.showInternalMessageDialog(Desktop.desktop,
                                            "Couldn't read the pasted text.\n" +
                                            "Formats currently supported are\n" +
                                            "Fasta, MSF, Clustal, BLC, PIR, MSP, and PFAM",
                                            "Error parsing text",
                                            JOptionPane.WARNING_MESSAGE);
    }
  }

  public void cancel_actionPerformed(ActionEvent e)
  {
    try
    {
      this.setClosed(true);
    }
    catch (Exception ex)
    {
    }
  }
}
